BezierHeader class

bezier container,if you need to implements indicator with bezier ,you can use consider about use this this will add the bezier container effect

See also:

BezierCircleHeader, bezier container +circle progress indicator

Inheritance

Constructors

BezierHeader({Widget child = const Text(""), OffsetCallBack? onOffsetChange, ModeChangeCallBack? onModeChange, VoidFutureCallBack? readyRefresh, bool enableChildOverflow = false, VoidFutureCallBack? endRefresh, VoidCallback? onResetValue, BezierDismissType dismissType = BezierDismissType.RectSpread, double rectHeight = 70, Color? bezierColor})

Properties

bezierColor → Color?
final
child → Widget
final
completeDuration → Duration
the stopped time when refresh complete or fail
finalinherited
dismissType → BezierDismissType
final
enableChildOverflow → bool
final
endRefresh → VoidFutureCallBack?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
the visual extent indicator
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset → double
finalinherited
onModeChange → ModeChangeCallBack?
final
onOffsetChange → OffsetCallBack?
final
onResetValue → VoidCallback?
final
readyRefresh → VoidFutureCallBack?
final
rectHeight → double
final
refreshStyle → RefreshStyle?
refresh display style
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited