ClassicFooter class

the most common indicator,combine with a text and a icon

Inheritance

Constructors

ClassicFooter({Key? key, VoidCallback? onClick, LoadStyle loadStyle = LoadStyle.ShowAlways, double height = 60.0, OuterBuilder? outerBuilder, TextStyle textStyle = const TextStyle(color: Colors.grey), String? loadingText, String? noDataText, Widget? noMoreIcon, String? idleText, String? failedText, String? canLoadingText, Widget? failedIcon = const Icon(Icons.error, color: Colors.grey), IconPosition iconPos = IconPosition.left, double spacing = 15.0, Duration completeDuration = const Duration(milliseconds: 300), Widget? loadingIcon, Widget? canLoadingIcon = const Icon(Icons.autorenew, color: Colors.grey), Widget? idleIcon = const Icon(Icons.arrow_upward, color: Colors.grey)})
const

Properties

canLoadingIcon → Widget?
final
canLoadingText → String?
final
completeDuration → Duration
notice that ,this attrs only works for LoadStyle.ShowWhenLoading
final
failedIcon → Widget?
final
failedText → String?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
the visual extent indicator
finalinherited
iconPos → IconPosition
final
idleIcon → Widget?
final
idleText → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingIcon → Widget?
final
loadingText → String?
final
loadStyle → LoadStyle
load more display style
finalinherited
noDataText → String?
final
noMoreIcon → Widget?
final
onClick → VoidCallback?
callback when user click footer
finalinherited
outerBuilder → OuterBuilder?
a builder for re wrap child,If you need to change the boxExtent or background,padding etc.you need outerBuilder to reWrap child example:
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
icon and text middle margin
final
textStyle → TextStyle
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited