LoadIndicatorState<T extends LoadIndicator> class abstract

Inheritance
Mixed-in types

Constructors

LoadIndicatorState()

Properties

activity → ScrollActivity?
no setterinherited
configuration ↔ RefreshConfiguration?
getter/setter pairinherited
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
floating ↔ dynamic
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ dynamic
getter/setter pairinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
refresher ↔ SmartRefresher?
getter/setter pairinherited
refresherState ↔ SmartRefresherState?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildContent(BuildContext context, LoadStatus mode) → Widget
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
disposeListener() → void
inherited
endLoading() → Future
override
enterLoading() → void
finishLoading() → void
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onModeChange(LoadStatus? mode) → void
inherited
onOffsetChange(double offset) → void
inherited
readyToLoad() → Future
when indicator is ready into refresh,it will call back and waiting for this function finish,then callback onRefresh
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resetValue() → void
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
update() → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited